#!/usr/bin/python3

"""
It is possible if and only if the number of U conveyors is at least N-1
and the number of R conveyors is at least M - 1.
If you those conditions are not satisfied then a monster in the bottom left
cannot reach the top right, no matter how the conveyors are arranged.

We can show it is always possible if those conditions are satisfied, by
using the following strategy.
We will place N-1 U conveyors and M-1 R conveyors along a "diagonal"
going from the bottom left to the top right. The remaining U and L
conveyors can be placed below and to the right of the diagonal and the
remaining D and R conveyors can be placed anywhere above and to the left
of the diagonal.
Start by placing all the L conveyors and all but N-1 of the U conveyors.
Fill from bottom to top, right to left, leaving the leftmost column empty.
Next, place the U and R conveyors that will form the diagonal by placing
these so that they lie next to the L and U conveyors that have already been
placed.
Finally, just fill the remaining spaces with the remaining D and R conveyors.

Submission author: Finn Lidbetter
"""


from sys import stdin


def solve():
    N, M, U, R, D, L = map(int, stdin.readline().split(' '))
    if U < N - 1 or R < M - 1:
        print("impossible")
        return
    grid = [
        [None for _ in range(M)] for _ in range(N)
    ]

    curr_row = N - 1
    # Place the spare U and L conveyors in the bottom right.
    while L > 0 or U > N - 1:
        for curr_col in range(M - 1, 0, -1):
            if L > 0:
                grid[curr_row][curr_col] = 'L'
                L -= 1
            elif U > N - 1:
                grid[curr_row][curr_col] = 'U'
                U -= 1
        curr_row -= 1
    # Place the U and R conveyors along the diagonal.
    curr_row = N - 1
    curr_col = 0
    while curr_row != 0 or curr_col != M - 1:
        if curr_col + 1 < M and grid[curr_row][curr_col + 1] is None:
            grid[curr_row][curr_col] = 'R'
            R -= 1
            curr_col += 1
        elif curr_row - 1 >= 0 and grid[curr_row - 1][curr_col] is None:
            grid[curr_row][curr_col] = 'U'
            U -= 1
            curr_row -= 1
    grid[0][M - 1] = '*'
    # Place the spare D and R conveyors in the upper left.
    for row in range(N):
        for col in range(M):
            if grid[row][col] is not None:
                break
            if D > 0:
                grid[row][col] = 'D'
                D -= 1
            elif R > 0:
                grid[row][col] = 'R'
                R -= 1
    for row in range(N):
        print(''.join(grid[row]))

def main():
    t = int(stdin.readline())
    for i in range(t):
        solve()
        if i != t-1:
            print()

if __name__ == "__main__":
    main()
